Oempdegreedistrib(net, n.seeds, n.neigh, num.sam = 1, seeds = NULL)matrix where each row is an edge.
integer vector of length n.
The object can be created by local.network.MR.new5 or
it can be imported.
num.sam x n.seeds containing the
numeric ids of the seeds to initiate sampling. Each row of the matrix
corresponds to one LSMI sample. Note that this is an optional parameter.
WARNING: As of now, this feature is only supported when
parameter n.neigh is greater than zero.num.sam where each element
is a list containing three tables:
the frequency of degrees sampled from seeds,
non-seeds including duplicated nodes,
and non-seeds without duplications.num.sam where each element is a
vector containing the unique degree values sampled in each LSMI.num.sam where each element
is a list containing two tables based on different methods to
estimating the empirical distribution from the network sample
(One list per LSMI).num.sam where each element
is a vector of unique degree values sampled solely from seeds
(One vector per LSMI).num.sam where each
element is a vector of unique degree values sampled
solely from non-seeds
(One vector per LSMI).
Note: This item is unreported when n.neigh equals zero.num.sam where each
element is the proportion of seeds with degree zero.
(One element per LSMI).num.sam where each
element is the sample mean of the seeds.
Note that This is unreported when n.neigh equals zero.num.sam x n.seeds with
the numeric seed ids. Each row corresponds to one LSMI.num.sam where each element is
vector containing the numeric ids of the nodes sampled using LSMI
(One element per LSMI). Note: nodes_of_LSMI is unreported when
n.neigh equals zero.net <- artificial_networks[[1]]
sam.out <- Oempdegreedistrib(net = net, n.seeds = 40, n.neigh = 1, num.sam = 1)
Run the code above in your browser using DataLab